XCODE_SCHEME_ADDRESS_SANITIZER_USE_AFTER_RETURN
-----------------------------------------------

Whether to enable ``Detect use of stack after return``
in the Diagnostics section of the generated Xcode scheme.

This property is initialized by the value of the variable
:variable:`CMAKE_XCODE_SCHEME_ADDRESS_SANITIZER_USE_AFTER_RETURN`
if it is set when a target is created.

Please refer to the :variable:`CMAKE_XCODE_GENERATE_SCHEME` variable
documentation to see all Xcode schema related properties.
